==> training-sys-facade-3.2.2.4-sources.jar: cn/smarthse/radiationTraining/modules/sys/param/order/UserAddOrderParam.java <==
package cn.smarthse.radiationTraining.modules.sys.param.order;

import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import java.io.Serializable;
import java.math.BigDecimal;
import java.time.LocalDate;

/**
 * 添加订单-表单(用户)
 *
 * @Author liaoly(廖凌云) [1302013247@qq.com]
 * @Date 2021年8月2日 下午1:50:23
 */
@Data
public class UserAddOrderParam implements Serializable {

    private static final long serialVersionUID = 71562368475698116L;

    @ApiModelProperty("套餐id")
    private Long comboId;

    @ApiModelProperty("付费类型(1-线上支付; 2-线下支付；3-赠送)")
    private Integer payType = 1;
    
    @ApiModelProperty(value = "订单类型(1-会员开通、2-会员续费、7-单位会员开通、8-个人会员开通、9-单位会员续费、10-个人会员续费、3-商务合作-签约、4-商务合作-续签、5-职业健康管理员报名、6-培训资源下载)", hidden = true)
    private Integer orderType;
    
    @ApiModelProperty(value = "创建类型(1-用户创建，2-后台创建)", hidden = true)
    private Integer sourceType = 1;
    
    @ApiModelProperty(value = "关联账号id", hidden = true)
    private Long userId;
    
    @ApiModelProperty(value = "关联账号", hidden = true)
    private String username;
    
    @ApiModelProperty(value = "用户类型(2-个人端，3-企业端)", hidden = true)
    private Integer userType;

    public UserAddOrderParam() {
    }

    public UserAddOrderParam(Long comboId, Long userId, String username, Integer payType, Integer orderType,
                         Integer sourceType, BigDecimal payMoney, LocalDate contractDate, LocalDate expireDate) {
        this.comboId = comboId;
        this.payType = payType;
        this.orderType = orderType;
        this.sourceType = sourceType;
        this.userId = userId;
        this.username = username;
    }
}

==> training-sys-facade-4.0.0-sources.jar: cn/smarthse/radiationTraining/modules/sys/param/order/UserAddOrderParam.java <==
package cn.smarthse.radiationTraining.modules.sys.param.order;

import lombok.Data;

import java.io.Serializable;
import java.math.BigDecimal;
import java.time.LocalDate;

/**
 * 添加订单-表单(用户)
 *
 * @Author liaoly(廖凌云) [1302013247@qq.com]
 * @Date 2021年8月2日 下午1:50:23
 */
@Data
public class UserAddOrderParam implements Serializable {

    private static final long serialVersionUID = 71562368475698116L;

//    @ApiModelProperty("套餐id")
    private Long comboId;

//    @ApiModelProperty("付费类型(1-线上支付; 2-线下支付；3-赠送)")
    private Integer payType = 1;
    
//    @ApiModelProperty(value = "订单类型(1-会员开通、2-会员续费、7-单位会员开通、8-个人会员开通、9-单位会员续费、10-个人会员续费、3-商务合作-签约、4-商务合作-续签、5-职业健康管理员报名、6-培训资源下载)", hidden = true)
    private Integer orderType;
    
//    @ApiModelProperty(value = "创建类型(1-用户创建，2-后台创建)", hidden = true)
    private Integer sourceType = 1;
    
//    @ApiModelProperty(value = "关联账号id", hidden = true)
    private Long userId;
    
//    @ApiModelProperty(value = "关联账号", hidden = true)
    private String username;
    
//    @ApiModelProperty(value = "用户类型(2-个人端，3-企业端)", hidden = true)
    private Integer userType;

    public UserAddOrderParam() {
    }

    public UserAddOrderParam(Long comboId, Long userId, String username, Integer payType, Integer orderType,
                         Integer sourceType, BigDecimal payMoney, LocalDate contractDate, LocalDate expireDate) {
        this.comboId = comboId;
        this.payType = payType;
        this.orderType = orderType;
        this.sourceType = sourceType;
        this.userId = userId;
        this.username = username;
    }
}
